@@ -1,4 +1,6 @@
 import datetime
+import math
+import time
 
 import urwid
 
@@ -16,14 +18,17 @@ class Dashboard(urwid.WidgetWrap):
 
         self._clients = clients
 
-        self._list_box = None
         self._content_walker = None
         self._interval = update_interval
+        self._last_update = time.time()
+        self._list_box = None
         self._sections = {}
         self._time = None
+        self._time_until_update = None
+        self._update_duration = 0
 
         self.overview_window()
-        self.update_time()
+        self.update_time(update_interval)
 
         super(Dashboard, self).__init__(self.main_window())
 
@@ -94,12 +99,15 @@ class Dashboard(urwid.WidgetWrap):
     def _now(self):
         return datetime.datetime.now()
 
-    def update_time(self):
+    def update_time(self, seconds_until_update):
         time_string = self._now().strftime("%H:%M:%S")
+        update = "Updating in {0:.0f}s".format(seconds_until_update)
         if self._time is None:
             self._time = util.subtle(time_string, align="center")
+            self._time_until_update = util.subtle(update, align="center")
         else:
             self._time.set_text(("subtle", time_string))
+            self._time_until_update.set_text(("subtle", update))
 
     def menu(self):
 
@@ -108,7 +116,7 @@ class Dashboard(urwid.WidgetWrap):
             util.subtle("v{0}".format(tripleodash.RELEASE_STRING),
                         align="center"),
             self._time,
-            urwid.Divider(),
+            self._time_until_update,
             urwid.Divider(),
             util.button("Overview", self.overview_window),
             util.button("Nodes", self.nodes_window),
@@ -121,9 +129,26 @@ class Dashboard(urwid.WidgetWrap):
         w.set_focus(3)
         return w
 
+    def _update(self, loop=None, user_data=None):
+        now = time.time()
+        self.update_content()
+        self._last_update = time.time()
+        self._update_duration = self._last_update - now
+
     def tick(self, loop=None, user_data=None):
 
-        self.update_time()
-        self.update_content()
+        # Find out how long the last update took and use that as the interval
+        # this time. Otherwise the UI will be frozen more than 50% of the time.
+        # This still isn't ideal, it would be much better if the update was
+        # non-blocking but until we can do this it will be a bit nicer to use.
+        now = time.time()
+        interval = max(self._interval, self._update_duration)
 
-        self.animate_alarm = self._loop.set_alarm_in(self._interval, self.tick)
+        seconds_until_update = math.ceil(interval - (now - self._last_update))
+        self.update_time(seconds_until_update)
+
+        if seconds_until_update <= 0:
+            self._time_until_update.set_text(("subtle", "Updating..."))
+            self.animate_alarm = self._loop.set_alarm_in(0.1, self._update)
+
+        self.animate_alarm = self._loop.set_alarm_in(1, self.tick)
